Method: DoubleEntry::AggregateArray#filter

Defined in:
lib/double_entry/aggregate_array.rb

#filterObject (readonly)

An AggregateArray is awesome It is useful for making reports It is basically an array of aggregate results, representing a column of data in a report.

For example, you could request all sales broken down by month and it would return an array of values



11
12
13
# File 'lib/double_entry/aggregate_array.rb', line 11

def filter
  @filter
end