Method: DoubleEntry::Reporting#aggregate_array
- Defined in:
- lib/double_entry/reporting.rb
#aggregate_array(function, account, code, options = {}) ⇒ Array[Money/Fixnum]
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Perform an aggregate calculation on a set of transfers for an account and return the results in an array partitioned by a time range type.
The transfers included in the calculation can be limited by a time range and provided custom filters.
105 106 107 |
# File 'lib/double_entry/reporting.rb', line 105 def aggregate_array(function, account, code, = {}) AggregateArray.new(function, account, code, ) end |